@@ -4,6 +4,7 @@ import pickle
 from collections import OrderedDict
 from collections.abc import AsyncIterable, Iterable, Iterator
 from itertools import chain, islice
+from os import PathLike
 from pathlib import Path
 from types import TracebackType
 from typing import Any, Final, Generic, Optional, SupportsIndex, Type, TypeVar, Union, overload
@@ -59,7 +60,7 @@ class BigList(ViewableMutableSequence[T], Generic[T]):
             "The folders containing all of the files.",
     }
 
-    def __init__(self: Self, path: Union[Path, str], *paths: Union[Path, str]) -> None:
+    def __init__(self: Self, path: Union[PathLike, bytes, str], *paths: Union[PathLike, bytes, str]) -> None:
         paths = {Path(path).resolve() for path in paths}
         paths.add(Path(path).resolve())
         paths = sorted(paths)
@@ -566,8 +567,6 @@ class BigList(ViewableMutableSequence[T], Generic[T]):
         return (i, index)
 
     def _fenwick_update(self: Self, index: int, value: int, /) -> None:
-        if value == 0:
-            return
         index = range(len(self._lens))[index] + 1
         self._lens[index - 1] += value
         fenwick = self._fenwick
@@ -737,7 +736,6 @@ class BigList(ViewableMutableSequence[T], Generic[T]):
                 with open(filename, mode="wb") as file:
                     pickle.dump(iterable[i : i + CHUNKSIZE_EXTENDED], file)
                 filenames.append(filename)
-                self._len += len(chunk)
             if len(iterable) == offset:
                 return
             i = len(self._lens)
